Class: IERS::TaiUtcDrift::Segment Private
- Inherits:
-
Data
- Object
- Data
- IERS::TaiUtcDrift::Segment
- Defined in:
- lib/iers/tai_utc_drift.rb
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Instance Attribute Summary collapse
-
#offset ⇒ Rational
readonly
TAI-UTC in seconds at reference_mjd (not at start_mjd: several segments measure their rate from an earlier MJD).
-
#rate ⇒ Rational
readonly
seconds of TAI-UTC per day of MJD.
-
#reference_mjd ⇒ Integer
readonly
the MJD the rate is measured from.
-
#start_mjd ⇒ Integer
readonly
first MJD the segment applies to.
Instance Attribute Details
#offset ⇒ Rational (readonly)
TAI-UTC in seconds at reference_mjd (not at start_mjd: several segments measure their rate from an earlier MJD)
23 24 25 |
# File 'lib/iers/tai_utc_drift.rb', line 23 def offset @offset end |
#rate ⇒ Rational (readonly)
seconds of TAI-UTC per day of MJD
23 24 25 |
# File 'lib/iers/tai_utc_drift.rb', line 23 def rate @rate end |
#reference_mjd ⇒ Integer (readonly)
the MJD the rate is measured from
23 24 25 |
# File 'lib/iers/tai_utc_drift.rb', line 23 def reference_mjd @reference_mjd end |
#start_mjd ⇒ Integer (readonly)
first MJD the segment applies to
23 24 25 |
# File 'lib/iers/tai_utc_drift.rb', line 23 def start_mjd @start_mjd end |